@@ -1,7 +1,7 @@
 // qjackctl.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -246,7 +246,17 @@ public:
 		return QApplication::x11EventFilter(pEv);
 	}
 #endif
-	
+
+	// Session shutdown handler.
+	void commitData(QSessionManager& sm)
+	{
+		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+		if (pMainForm)
+			pMainForm->setQuitForce(true);
+
+		QApplication::commitData(sm);
+	}
+
 private:
 
 	// Translation support.
@@ -287,7 +297,8 @@ void stacktrace ( int signo )
 	signal(signo, SIG_DFL);
 
 	static const char *shell  = "/bin/sh";
-	static const char *format = "gdb -q --batch --pid=%d --eval-command=bt";
+	static const char *format = "gdb -q --batch --pid=%d"
+		" --eval-command='thread apply all bt'";
 
 	snprintf(cmd, sizeof(cmd), format, (int) getpid());
 
