@@ -1,7 +1,7 @@
 // qjackctlSessionForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -59,22 +59,26 @@ public:
 
 	// Recent session directories and save type accessors.
 	const QStringList& sessionDirs() const;
-	int sessionSaveType() const;
+	bool isSaveSessionVersion() const;
 
 	// Recent menu accessor.
 	QMenu *recentMenu() const;
 
+	// Save menu accessor.
+	QMenu *saveMenu() const;
+
 	void stabilizeForm(bool bEnabled);
 
 public slots:
 
 	void loadSession();
-	void saveSession();
 
 	void saveSessionSave();
 	void saveSessionSaveAndQuit();
 	void saveSessionSaveTemplate();
 
+	void saveSessionVersion(bool);
+
 	void updateSession();
 
 protected slots:
@@ -115,6 +119,9 @@ private:
 	// Recent session menu.
 	QMenu *m_pRecentMenu;
 
+	// Save session menu.
+	QMenu *m_pSaveMenu;
+
 	// Session directory history.
 	QStringList m_sessionDirs;
 };
