@@ -137,6 +137,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ServerComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(settingsChanged()));
+	QObject::connect(m_ui.ServerNameComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(settingsChanged()));
 	QObject::connect(m_ui.DriverComboBox,
 		SIGNAL(activated(int)),
 		SLOT(settingsChanged()));
@@ -286,9 +289,6 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.XrunRegexComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.XrunIgnoreFirstCheckBox,
-		SIGNAL(stateChanged(int)),
-		SLOT(optionsChanged()));
 	QObject::connect(m_ui.ActivePatchbayCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -425,11 +425,11 @@ qjackctlSetupForm::qjackctlSetupForm (
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
 
-	QObject::connect(m_ui.OkPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(accepted()),
 		SLOT(accept()));
-	QObject::connect(m_ui.CancelPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(rejected()),
 		SLOT(reject()));
 
 	// Try to restore old window positioning.
@@ -473,6 +473,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 
 	// Load combo box history...
 	m_pSetup->loadComboBoxHistory(m_ui.ServerComboBox);
+	m_pSetup->loadComboBoxHistory(m_ui.ServerNameComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.InterfaceComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.InDeviceComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.OutDeviceComboBox);
@@ -501,7 +502,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.StdoutCaptureCheckBox->setChecked(m_pSetup->bStdoutCapture);
 	setComboBoxCurrentText(m_ui.XrunRegexComboBox,
 		m_pSetup->sXrunRegex);
-	m_ui.XrunIgnoreFirstCheckBox->setChecked(m_pSetup->bXrunIgnoreFirst);
 	m_ui.ActivePatchbayCheckBox->setChecked(m_pSetup->bActivePatchbay);
 	setComboBoxCurrentText(m_ui.ActivePatchbayPathComboBox,
 		m_pSetup->sActivePatchbayPath);
@@ -654,6 +654,10 @@ void qjackctlSetupForm::changePreset ( const QString& sPreset )
 	qjackctlPreset preset;
 	if (m_pSetup->loadPreset(preset, sPreset)) {
 		setComboBoxCurrentText(m_ui.ServerComboBox, preset.sServer);
+		setComboBoxCurrentText(m_ui.ServerNameComboBox,
+			preset.sServerName.isEmpty()
+			? m_pSetup->sDefPresetName
+			: preset.sServerName);
 		m_ui.RealtimeCheckBox->setChecked(preset.bRealtime);
 		m_ui.SoftModeCheckBox->setChecked(preset.bSoftMode);
 		m_ui.MonitorCheckBox->setChecked(preset.bMonitor);
@@ -720,6 +724,7 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 	// Unload settings.
 	qjackctlPreset preset;
 	preset.sServer      = m_ui.ServerComboBox->currentText();
+	preset.sServerName  = m_ui.ServerNameComboBox->currentText();
 	preset.bRealtime    = m_ui.RealtimeCheckBox->isChecked();
 	preset.bSoftMode    = m_ui.SoftModeCheckBox->isChecked();
 	preset.bMonitor     = m_ui.MonitorCheckBox->isChecked();
@@ -753,6 +758,8 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 #ifdef CONFIG_JACK_MIDI
 	preset.sMidiDriver  = m_ui.MidiDriverComboBox->currentText();
 #endif
+	if (preset.sServerName == m_pSetup->sDefPresetName)
+		preset.sServerName.clear();
 	if (preset.sInterface == m_pSetup->sDefPresetName)
 		preset.sInterface.clear();
 	if (preset.sInDevice == m_pSetup->sDefPresetName)
@@ -937,13 +944,13 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
 	m_ui.InLatencyTextLabel->setEnabled((bInEnabled && !bNet)
-		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
+		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
 	m_ui.InLatencySpinBox->setEnabled((bInEnabled && !bNet)
-		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
+		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
 	m_ui.OutLatencyTextLabel->setEnabled((bOutEnabled && !bNet)
-		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
+		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 	m_ui.OutLatencySpinBox->setEnabled((bOutEnabled && !bNet)
-		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
+		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
 	computeLatency();
 }
@@ -1016,7 +1023,7 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.ChanSpinBox->setEnabled(bPortaudio);
 
 	int  iAudio   = m_ui.AudioComboBox->currentIndex();
-	bool bEnabled = bAlsa;
+	bool bEnabled = (bAlsa || bPortaudio);
 	if (bEnabled && iAudio == QJACKCTL_DUPLEX) {
 		const QString& sInDevice  = m_ui.InDeviceComboBox->currentText();
 		const QString& sOutDevice = m_ui.OutDeviceComboBox->currentText();
@@ -1024,10 +1031,10 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 					sOutDevice.isEmpty() || sOutDevice == m_pSetup->sDefPresetName);
 	}
 
-	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire || bPortaudio);
+	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire);
 	m_ui.InterfaceTextLabel->setEnabled(bInterface);
 	m_ui.InterfaceComboBox->setEnabled(bInterface);
-	m_ui.InterfaceToolButton->setEnabled(bEnabled || bCoreaudio || bPortaudio);
+	m_ui.InterfaceToolButton->setEnabled(bEnabled || bCoreaudio);
 	if (!bInterface)
 		setComboBoxCurrentText(m_ui.InterfaceComboBox, m_pSetup->sDefPresetName);
 
@@ -1082,7 +1089,6 @@ void qjackctlSetupForm::stabilizeForm (void)
 	bEnabled = m_ui.StdoutCaptureCheckBox->isChecked();
 	m_ui.XrunRegexTextLabel->setEnabled(bEnabled);
 	m_ui.XrunRegexComboBox->setEnabled(bEnabled);
-	m_ui.XrunIgnoreFirstCheckBox->setEnabled(bEnabled);
 
 	bEnabled = m_ui.ActivePatchbayCheckBox->isChecked();
 	m_ui.ActivePatchbayPathComboBox->setEnabled(bEnabled);
@@ -1130,7 +1136,7 @@ void qjackctlSetupForm::stabilizeForm (void)
 
 	changeDriverUpdate(m_ui.DriverComboBox->currentText(), false);
 
-	m_ui.OkPushButton->setEnabled(bValid);
+	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
 }
 
 
@@ -1496,6 +1502,7 @@ void qjackctlSetupForm::symbolMenu( QLineEdit *pLineEdit,
 
 	menu.addAction("%P" + s + tr("&Preset Name"));
 	menu.addSeparator();
+	menu.addAction("%N" + s + tr("&Server Name"));
 	menu.addAction("%s" + s + tr("&Server Path"));
 	menu.addAction("%d" + s + tr("&Driver"));
 	menu.addAction("%i" + s + tr("&Interface"));
@@ -1685,7 +1692,7 @@ void qjackctlSetupForm::toggleDisplayEffect ( bool bOn )
 	QPalette pal;
 	pal.setColor(QPalette::Foreground, Qt::green);
 	if (bOn) {
-		QPixmap pm(":/icons/displaybg1.png");
+		QPixmap pm(":/images/displaybg1.png");
 		pal.setBrush(QPalette::Background, QBrush(pm));
 	} else {
 		pal.setColor(QPalette::Background, Qt::black);
@@ -1766,7 +1773,6 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->sPostShutdownScriptShell = m_ui.PostShutdownScriptShellComboBox->currentText();
 		m_pSetup->bStdoutCapture           = m_ui.StdoutCaptureCheckBox->isChecked();
 		m_pSetup->sXrunRegex               = m_ui.XrunRegexComboBox->currentText();
-		m_pSetup->bXrunIgnoreFirst         = m_ui.XrunIgnoreFirstCheckBox->isChecked();
 		m_pSetup->bActivePatchbay          = m_ui.ActivePatchbayCheckBox->isChecked();
 		m_pSetup->sActivePatchbayPath      = m_ui.ActivePatchbayPathComboBox->currentText();
 #ifdef CONFIG_AUTO_REFRESH
@@ -1813,6 +1819,7 @@ void qjackctlSetupForm::accept (void)
 
 	// Save combobox history...
 	m_pSetup->saveComboBoxHistory(m_ui.ServerComboBox);
+	m_pSetup->saveComboBoxHistory(m_ui.ServerNameComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.InterfaceComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.InDeviceComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.OutDeviceComboBox);
