@@ -22,6 +22,8 @@
 #include "qjackctlAbout.h"
 #include "qjackctlSocketForm.h"
 
+#include "qjackctlMainForm.h"
+
 #include "qjackctlPatchbay.h"
 #include "qjackctlConnectAlias.h"
 
@@ -45,8 +47,7 @@ qjackctlSocketForm::qjackctlSocketForm (
 	m_ui.setupUi(this);
 
 	m_pSocketList  = NULL;
-	m_pJackClient  = NULL;
-	m_pAlsaSeq     = NULL;
+	m_bSocketNew   = false;
 	m_ppPixmaps    = NULL;
 	m_iDirtyCount  = 0;
 
@@ -128,11 +129,11 @@ qjackctlSocketForm::qjackctlSocketForm (
 		SIGNAL(activated(int)),
 		SLOT(changed()));
 
-	QObject::connect(m_ui.OkPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(accepted()),
 		SLOT(accept()));
-	QObject::connect(m_ui.CancelPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(rejected()),
 		SLOT(reject()));
 }
 
@@ -160,6 +161,13 @@ void qjackctlSocketForm::setSocketList ( qjackctlSocketList *pSocketList )
 }
 
 
+// Socket new flag.
+void qjackctlSocketForm::setSocketNew ( bool bSocketNew )
+{
+	m_bSocketNew = bSocketNew;
+}
+
+
 // Pixmap utility methods.
 void qjackctlSocketForm::setPixmaps ( QPixmap **ppPixmaps )
 {
@@ -167,20 +175,6 @@ void qjackctlSocketForm::setPixmaps ( QPixmap **ppPixmaps )
 }
 
 
-// JACK client accessor.
-void qjackctlSocketForm::setJackClient ( jack_client_t *pJackClient )
-{
-	m_pJackClient = pJackClient;
-}
-
-
-// ALSA sequencer accessor.
-void qjackctlSocketForm::setAlsaSeq ( snd_seq_t *pAlsaSeq )
-{
-	m_pAlsaSeq = pAlsaSeq;
-}
-
-
 // Socket type and exclusiveness editing enablement.
 void qjackctlSocketForm::setConnectCount ( int iConnectCount )
 {
@@ -281,7 +275,8 @@ void qjackctlSocketForm::save ( qjackctlPatchbaySocket *pSocket )
 // Stabilize current state form.
 void qjackctlSocketForm::stabilizeForm (void)
 {
-	m_ui.OkPushButton->setEnabled(validateForm());
+	m_ui.DialogButtonBox->button(
+		QDialogButtonBox::Ok)->setEnabled(validateForm());
 
 	QTreeWidgetItem *pItem = m_ui.PlugListView->currentItem();
 	if (pItem) {
@@ -329,16 +324,18 @@ void qjackctlSocketForm::accept (void)
 		return;
 
 	// Check if a socket with the same name already exists...
-	QListIterator<qjackctlSocketItem *> iter(m_pSocketList->sockets());
-	while (iter.hasNext()) {
-		const QString& sSocketName = iter.next()->socketName();
-		if (m_ui.SocketNameLineEdit->text() == sSocketName) {
-			QMessageBox::critical(this,
-				tr("Error") + " - " QJACKCTL_SUBTITLE1,
-				tr("A socket named \"%1\" already exists.")
-				.arg(sSocketName), QMessageBox::Cancel);
-			// Reject.
-			return;
+	if (m_bSocketNew) {
+		QListIterator<qjackctlSocketItem *> iter(m_pSocketList->sockets());
+		while (iter.hasNext()) {
+			const QString& sSocketName = iter.next()->socketName();
+			if (m_ui.SocketNameLineEdit->text() == sSocketName) {
+				QMessageBox::critical(this,
+					tr("Error") + " - " QJACKCTL_SUBTITLE1,
+					tr("A socket named \"%1\" already exists.")
+					.arg(sSocketName), QMessageBox::Cancel);
+				// Reject.
+				return;
+			}
 		}
 	}
 
@@ -392,11 +389,11 @@ void qjackctlSocketForm::addPlug (void)
 	if (!sPlugName.isEmpty()) {
 		QTreeWidgetItem *pItem = m_ui.PlugListView->currentItem();
 		if (pItem)
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, false);
-#endif
+		#endif
 		pItem = new QTreeWidgetItem(m_ui.PlugListView, pItem);
 		if (pItem) {
 			pItem->setText(0, sPlugName);
@@ -413,11 +410,11 @@ void qjackctlSocketForm::addPlug (void)
 			}
 			if (pXpmPlug)
 				pItem->setIcon(0, QIcon(*pXpmPlug));
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, true);
-#endif
+		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 		m_ui.PlugNameComboBox->setEditText(QString::null);
@@ -456,18 +453,18 @@ void qjackctlSocketForm::moveUpPlug (void)
 	if (pItem) {
 		int iItem = m_ui.PlugListView->indexOfTopLevelItem(pItem);
 		if (iItem > 0) {
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, false);
-#endif
+		#endif
 			pItem = m_ui.PlugListView->takeTopLevelItem(iItem);
 			m_ui.PlugListView->insertTopLevelItem(iItem - 1, pItem);
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, true);
-#endif
+		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 	}
@@ -484,18 +481,18 @@ void qjackctlSocketForm::moveDownPlug (void)
 		int iItem = m_ui.PlugListView->indexOfTopLevelItem(pItem);
 		int iItemCount = m_ui.PlugListView->topLevelItemCount();
 		if (iItem < iItemCount - 1) {
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, false);
-#endif
+		#endif
 			pItem = m_ui.PlugListView->takeTopLevelItem(iItem);
 			m_ui.PlugListView->insertTopLevelItem(iItem + 1, pItem);
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-#else
+		#else
 			m_ui.PlugListView->setItemSelected(pItem, true);
-#endif
+		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 	}
@@ -543,7 +540,7 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 
 	// Build the add plug sub-menu...
 	QMenu *pAddPlugMenu = menu.addMenu(
-		QIcon(":/icons/add1.png"), tr("Add Plug"));
+		QIcon(":/images/add1.png"), tr("Add Plug"));
 	int iIndex = 0;
 	for (iIndex = 0; iIndex < m_ui.PlugNameComboBox->count(); iIndex++) {
 		pAction = pAddPlugMenu->addAction(
@@ -556,17 +553,17 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 	pAddPlugMenu->setEnabled(iIndex > 0);
 	// Build the plug context menu...
 	bool bEnabled = (pItem != NULL);
-	pAction = menu.addAction(QIcon(":/icons/edit1.png"),
+	pAction = menu.addAction(QIcon(":/images/edit1.png"),
 		tr("Edit"), this, SLOT(editPlug()));
 	pAction->setEnabled(bEnabled);
-	pAction = menu.addAction(QIcon(":/icons/remove1.png"),
+	pAction = menu.addAction(QIcon(":/images/remove1.png"),
 		tr("Remove"), this, SLOT(removePlug()));
 	pAction->setEnabled(bEnabled);
 	menu.addSeparator();
-	pAction = menu.addAction(QIcon(":/icons/up1.png"),
+	pAction = menu.addAction(QIcon(":/images/up1.png"),
 		tr("Move Up"), this, SLOT(moveUpPlug()));
 	pAction->setEnabled(bEnabled && iItem > 0);
-	pAction = menu.addAction(QIcon(":/icons/down1.png"),
+	pAction = menu.addAction(QIcon(":/images/down1.png"),
 		tr("Move Down"), this, SLOT(moveDownPlug()));
 	pAction->setEnabled(bEnabled && iItem < iItemCount - 1);
 
@@ -576,7 +573,12 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 
 void qjackctlSocketForm::updateJackClients ( int iSocketType )
 {
-	if (m_pJackClient == NULL)
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
+	jack_client_t *pJackClient = pMainForm->jackClient();
+	if (pJackClient == NULL)
 		return;
 
 	const char *pszJackPortType = JACK_DEFAULT_AUDIO_TYPE;
@@ -592,8 +594,8 @@ void qjackctlSocketForm::updateJackClients ( int iSocketType )
 	const QIcon icon(*m_ppPixmaps[iPixmap]);
 
 	// Grab all client ports.
-	const char **ppszClientPorts = jack_get_ports(m_pJackClient,
-		NULL, pszJackPortType,
+	const char **ppszClientPorts = jack_get_ports(
+		pJackClient, NULL, pszJackPortType,
 		(bReadable ? JackPortIsOutput : JackPortIsInput));
 	if (ppszClientPorts) {
 		int iClientPort = 0;
@@ -622,11 +624,19 @@ void qjackctlSocketForm::updateJackClients ( int iSocketType )
 // ALSA client names refreshner.
 void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 {
-	if (m_pAlsaSeq == NULL)
+	if (iSocketType != QJACKCTL_SOCKETTYPE_ALSA_MIDI)
 		return;
 
 #ifdef CONFIG_ALSA_SEQ
 
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
+	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
+	if (pAlsaSeq == NULL)
+		return;
+
 	bool bReadable = m_pSocketList->isReadable();
 	const QIcon icon(*m_ppPixmaps[QJACKCTL_XPM_MIDI_CLIENT]);
 
@@ -642,7 +652,7 @@ void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 	snd_seq_client_info_alloca(&pClientInfo);
 	snd_seq_port_info_alloca(&pPortInfo);
 	snd_seq_client_info_set_client(pClientInfo, -1);
-	while (snd_seq_query_next_client(m_pAlsaSeq, pClientInfo) >= 0) {
+	while (snd_seq_query_next_client(pAlsaSeq, pClientInfo) >= 0) {
 		int iAlsaClient = snd_seq_client_info_get_client(pClientInfo);
 		QString sClient
 			= qjackctlClientAlias::escapeRegExpDigits(
@@ -652,7 +662,7 @@ void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 			snd_seq_port_info_set_client(pPortInfo, iAlsaClient);
 			snd_seq_port_info_set_port(pPortInfo, -1);
 			while (!bExists
-				&& snd_seq_query_next_port(m_pAlsaSeq, pPortInfo) >= 0) {
+				&& snd_seq_query_next_port(pAlsaSeq, pPortInfo) >= 0) {
 				unsigned int uiPortCapability
 					= snd_seq_port_info_get_capability(pPortInfo);
 				if (((uiPortCapability & uiAlsaFlags) == uiAlsaFlags) &&
@@ -770,7 +780,12 @@ void qjackctlSocketForm::socketTypeChanged (void)
 // JACK client plugs refreshner.
 void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 {
-	if (m_pJackClient == NULL)
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
+	jack_client_t *pJackClient = pMainForm->jackClient();
+	if (pJackClient == NULL)
 		return;
 
 	const char *pszJackPortType = JACK_DEFAULT_AUDIO_TYPE;
@@ -789,8 +804,8 @@ void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 
 	bool bReadable = m_pSocketList->isReadable();
 	const QIcon icon(*m_ppPixmaps[iPixmap]);
-	const char **ppszClientPorts = jack_get_ports(m_pJackClient,
-		NULL, pszJackPortType,
+	const char **ppszClientPorts = jack_get_ports(
+		pJackClient, NULL, pszJackPortType,
 		(bReadable ? JackPortIsOutput : JackPortIsInput));
 	if (ppszClientPorts) {
 		int iClientPort = 0;
@@ -814,13 +829,19 @@ void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 // ALSA client plugs refreshner.
 void qjackctlSocketForm::updateAlsaPlugs ( int iSocketType )
 {
-	if (m_pAlsaSeq == NULL)
-		return;
 	if (iSocketType != QJACKCTL_SOCKETTYPE_ALSA_MIDI)
 		return;
 
 #ifdef CONFIG_ALSA_SEQ
 
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
+	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
+	if (pAlsaSeq == NULL)
+		return;
+
 	QString sClientName = m_ui.ClientNameComboBox->currentText();
 	if (sClientName.isEmpty())
 		return;
@@ -841,14 +862,14 @@ void qjackctlSocketForm::updateAlsaPlugs ( int iSocketType )
 	snd_seq_client_info_alloca(&pClientInfo);
 	snd_seq_port_info_alloca(&pPortInfo);
 	snd_seq_client_info_set_client(pClientInfo, -1);
-	while (snd_seq_query_next_client(m_pAlsaSeq, pClientInfo) >= 0) {
+	while (snd_seq_query_next_client(pAlsaSeq, pClientInfo) >= 0) {
 		int iAlsaClient = snd_seq_client_info_get_client(pClientInfo);
 		QString sClient = QString::fromUtf8(
 			snd_seq_client_info_get_name(pClientInfo));
 		if (iAlsaClient > 0 && rxClientName.exactMatch(sClient)) {
 			snd_seq_port_info_set_client(pPortInfo, iAlsaClient);
 			snd_seq_port_info_set_port(pPortInfo, -1);
-			while (snd_seq_query_next_port(m_pAlsaSeq, pPortInfo) >= 0) {
+			while (snd_seq_query_next_port(pAlsaSeq, pPortInfo) >= 0) {
 				unsigned int uiPortCapability
 					= snd_seq_port_info_get_capability(pPortInfo);
 				if (((uiPortCapability & uiAlsaFlags) == uiAlsaFlags) &&
